# UserPermissionResource


## Enum

* `PROMPTS` (value: `'prompts'`)

* `RESPONSES` (value: `'responses'`)

* `RULES` (value: `'rules'`)

* `TASKS` (value: `'tasks'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


